==> jc-1.4.0.tar.gz: javax/swing/text/JTextComponent__24KeymapActionMap.h <==
// class javax.swing.text.JTextComponent$KeymapActionMap

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 93c843e5a4c9d4b3 javax_swing_ActionMap
// @dep_class 1f33ac5a7b464b5e javax_swing_text_JTextComponent__24KeymapActionMap

// header file dependencies
// @dep_header javax_swing_ActionMap

#include "javax/swing/ActionMap.h"

#ifndef _JC_javax_swing_text_JTextComponent__24KeymapActionMap_H_
#define _JC_javax_swing_text_JTextComponent__24KeymapActionMap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_Action$object;
struct _jc_javax_swing_text_JTextComponent$object;
struct _jc_javax_swing_text_Keymap$object;

// Typedefs
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$sub_refs	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$sub_refs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$sub_nonrefs	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$sub_nonrefs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$refs	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$refs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$nonrefs	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$nonrefs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$object;

typedef const struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$vmethods	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$vmethods;
typedef const struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$vtable	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$vtable;
typedef const struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$vtype	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$vtype;

// Constructors
extern void _jc_javax_swing_text_JTextComponent__24KeymapActionMap$method$_init$7c9889f92e4657d3(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object *, struct _jc_javax_swing_text_JTextComponent$object *, struct _jc_object *);

// Virtual methods
extern _jc_object_array *_jc_javax_swing_text_JTextComponent__24KeymapActionMap$method$allKeys$28a587fa8b6d067d(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object *);
extern struct _jc_object *_jc_javax_swing_text_JTextComponent__24KeymapActionMap$method$get$57242fb6550145ba(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object *, struct _jc_java_lang_Object$object *);
extern _jc_object_array *_jc_javax_swing_text_JTextComponent__24KeymapActionMap$method$keys$6ce94ae925da3576(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object *);
extern jint _jc_javax_swing_text_JTextComponent__24KeymapActionMap$method$size$345df5220fc60ade(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_JTextComponent__24KeymapActionMap$method_info$allKeys$28a587fa8b6d067d;
extern _jc_method _jc_javax_swing_text_JTextComponent__24KeymapActionMap$method_info$get$57242fb6550145ba;
extern _jc_method _jc_javax_swing_text_JTextComponent__24KeymapActionMap$method_info$keys$6ce94ae925da3576;
extern _jc_method _jc_javax_swing_text_JTextComponent__24KeymapActionMap$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$vmethods {
	_jc_object_array	*(*allKeys$28a587fa8b6d067d)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object *);
	struct _jc_object	*(*get$57242fb6550145ba)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object *, struct _jc_java_lang_Object$object *);
	_jc_object_array	*(*keys$6ce94ae925da3576)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object *);
};

// Vtable
struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_ActionMap$vmethods	javax_swing_ActionMap;
	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$vmethods	javax_swing_text_JTextComponent__24KeymapActionMap;
};

// Vtype
struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$vtype {
	_jc_type			type;
	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$sub_refs {
	struct _jc_object	*map;
	struct _jc_javax_swing_text_JTextComponent$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$refs {
    _jc_javax_swing_text_JTextComponent__24KeymapActionMap$sub_refs	javax_swing_text_JTextComponent__24KeymapActionMap;
    _jc_javax_swing_ActionMap$sub_refs	javax_swing_ActionMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_ActionMap$sub_nonrefs	javax_swing_ActionMap;
    _jc_javax_swing_text_JTextComponent__24KeymapActionMap$sub_nonrefs	javax_swing_text_JTextComponent__24KeymapActionMap;
};

// Object instance structure
struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object {
	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$vtype	*vtype;
	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_JTextComponent__24KeymapActionMap$vtype _jc_javax_swing_text_JTextComponent__24KeymapActionMap$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_JTextComponent__24KeymapActionMap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_JTextComponent__24KeymapActionMap$class_object;

#endif	/* _JC_javax_swing_text_JTextComponent__24KeymapActionMap_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/JTextComponent__24KeymapActionMap.h <==
// class javax.swing.text.JTextComponent$KeymapActionMap

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 93c843e5a4c9d4b3 javax_swing_ActionMap
// @dep_class 1f33ac5a7b464b5e javax_swing_text_JTextComponent__24KeymapActionMap

// header file dependencies
// @dep_header javax_swing_ActionMap

#include "javax/swing/ActionMap.h"

#ifndef _JC_javax_swing_text_JTextComponent__24KeymapActionMap_H_
#define _JC_javax_swing_text_JTextComponent__24KeymapActionMap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_Action$object;
struct _jc_javax_swing_text_JTextComponent$object;
struct _jc_javax_swing_text_Keymap$object;

// Typedefs
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$sub_refs	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$sub_refs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$sub_nonrefs	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$sub_nonrefs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$refs	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$refs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$nonrefs	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$nonrefs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$object;

typedef const struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$vmethods	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$vmethods;
typedef const struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$vtable	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$vtable;
typedef const struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$vtype	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$vtype;

// Constructors
extern void _jc_javax_swing_text_JTextComponent__24KeymapActionMap$method$_init$7c9889f92e4657d3(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object *, struct _jc_javax_swing_text_JTextComponent$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_javax_swing_text_JTextComponent__24KeymapActionMap$method$allKeys$28a587fa8b6d067d(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_text_JTextComponent__24KeymapActionMap$method$get$57242fb6550145ba(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_swing_text_JTextComponent__24KeymapActionMap$method$keys$6ce94ae925da3576(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_text_JTextComponent__24KeymapActionMap$method$size$345df5220fc60ade(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_JTextComponent__24KeymapActionMap$method_info$allKeys$28a587fa8b6d067d;
extern _jc_method _jc_javax_swing_text_JTextComponent__24KeymapActionMap$method_info$get$57242fb6550145ba;
extern _jc_method _jc_javax_swing_text_JTextComponent__24KeymapActionMap$method_info$keys$6ce94ae925da3576;
extern _jc_method _jc_javax_swing_text_JTextComponent__24KeymapActionMap$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$vmethods {
	_jc_object_array	*(*allKeys$28a587fa8b6d067d)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*get$57242fb6550145ba)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*keys$6ce94ae925da3576)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_ActionMap$vmethods	javax_swing_ActionMap;
	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$vmethods	javax_swing_text_JTextComponent__24KeymapActionMap;
};

// Vtype
struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$vtype {
	_jc_type			type;
	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$sub_refs {
	struct _jc_object	*map;
	struct _jc_javax_swing_text_JTextComponent$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$refs {
    _jc_javax_swing_text_JTextComponent__24KeymapActionMap$sub_refs	javax_swing_text_JTextComponent__24KeymapActionMap;
    _jc_javax_swing_ActionMap$sub_refs	javax_swing_ActionMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_ActionMap$sub_nonrefs	javax_swing_ActionMap;
    _jc_javax_swing_text_JTextComponent__24KeymapActionMap$sub_nonrefs	javax_swing_text_JTextComponent__24KeymapActionMap;
};

// Object instance structure
struct _jc_javax_swing_text_JTextComponent__24KeymapActionMap$object {
	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$vtype	*vtype;
	_jc_javax_swing_text_JTextComponent__24KeymapActionMap$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_JTextComponent__24KeymapActionMap$vtype _jc_javax_swing_text_JTextComponent__24KeymapActionMap$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_JTextComponent__24KeymapActionMap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_JTextComponent__24KeymapActionMap$class_object;

#endif	/* _JC_javax_swing_text_JTextComponent__24KeymapActionMap_H_ */
